"""jsonify tags arrays

Revision ID: 35edbc4fbde0
Revises: 6ff596e1d6c3
Create Date: 2018-11-13 17:05:22.323391

"""
from alembic import op
from sqlalchemy import text
import rapidjson as json


# revision identifiers, used by Alembic.
from feed_manager.sql.models import Report

revision = "35edbc4fbde0"
down_revision = "6ff596e1d6c3"
branch_labels = None
depends_on = None


def upgrade():
    # convert all report tags to json arrays
    conn = op.get_bind()
    for result in conn.execute(text("SELECT id, tags FROM reports")):
        tags = result["tags"]
        id = result["id"]

        if not tags:
            update_stmt = (
                Report.__table__.update().values({"tags": None}).where(Report.id == id)
            )
        else:
            try:
                json_tags = json.loads(tags)
            except:
                json_tags = None

            if isinstance(json_tags, list):
                tags = json_tags
            else:
                tags = tags.strip("[]")  # remove bounding brackets
                # split by comma and remove spaces and single quotes
                tags = [tag.strip(" '") for tag in tags.split(",")]

            update_stmt = (
                Report.__table__.update()
                .values({"tags": json.dumps(tags)})
                .where(Report.id == id)
            )

        conn.execute(update_stmt)


def downgrade():  # pragma: no cover
    # nothing to do
    pass
